ProxyInjectionSafariCustomProfileLauncher (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.browserlaunchers
Class ProxyInjectionSafariCustomProfileLauncher

    java.lang.Object
      org.openqa.selenium.server.browserlaunchers.AbstractBrowserLauncher
          org.openqa.selenium.server.browserlaunchers.SafariCustomProfileLauncher
              org.openqa.selenium.server.browserlaunchers.ProxyInjectionSafariCustomProfileLauncher

All Implemented Interfaces:
  BrowserLauncher

    public class ProxyInjectionSafariCustomProfileLauncher

extends SafariCustomProfileLauncher

launcher for Safari under proxy injection mode In proxy injection mode, the selenium server is a proxy for all traffic from the browser, not just traffic going to selenium-server URLs. The incoming HTML is modified to include selenium's JavaScript, which then controls the test page from within (as opposed to controlling the test page from a different window, as selenium remote control normally does).

Author:
  danielf

Field Summary

Fields inherited from class org.openqa.selenium.server.browserlaunchers.SafariCustomProfileLauncher
`browserInstallation, cmdarray, customProfileDir, exe, mpm, process, wpm`

Fields inherited from class org.openqa.selenium.server.browserlaunchers.AbstractBrowserLauncher
`browserConfigurationOptions, sessionId`

Constructor Summary
`ProxyInjectionSafariCustomProfileLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`

Method Summary
`protected void` | `changeRegistrySettings()`
`static void` | `setChangeMaxConnections(boolean changeMaxConnections)`

Methods inherited from class org.openqa.selenium.server.browserlaunchers.SafariCustomProfileLauncher
`close, ensureCleanSession, getProcess, launch, launchSafari, locateSafari, makeRedirectionHtml`

Methods inherited from class org.openqa.selenium.server.browserlaunchers.AbstractBrowserLauncher
`getConfiguration, getPort, launchHTMLSuite, launchRemoteSession`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### ProxyInjectionSafariCustomProfileLauncher

    public ProxyInjectionSafariCustomProfileLauncher(BrowserConfigurationOptions browserOptions,
                                                     RemoteControlConfiguration configuration,
                                                     java.lang.String sessionId,
                                                     java.lang.String browserLaunchLocation)

Method Detail

### changeRegistrySettings

    protected void changeRegistrySettings()
                                   throws java.io.IOException

  Overrides:
    `changeRegistrySettings` in class `SafariCustomProfileLauncher`
  Throws:
    `java.io.IOException`

### setChangeMaxConnections

    public static void setChangeMaxConnections(boolean changeMaxConnections)

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.